%                               -*- Mode: Rd -*- 
% addarrow.Rd --- 
% Author          : Claus Dethlefsen
% Created On      : Sat May 25 23:00:53 2002
% Last Modified By: Claus Dethlefsen
% Last Modified On: Tue Jul 22 14:57:45 2003
% Update Count    : 30
% Status          : Unknown, Use with caution!
% 

\name{addarrow}
\alias{addarrow}
%- Also NEED an `\alias' for EACH other topic documented here.
\alias{turnarrow}
\alias{removearrow}

\title{Adding/Turning/Removing arrows}

\description{Create all networks with exactly one arrow added/turned/removed.
}

\usage{
addarrow   (nw,df,prior,trylist=vector("list",nw$n)) 
turnarrow  (nw,df,prior,trylist=vector("list",nw$n)) 
removearrow(nw,df,prior,trylist=vector("list",nw$n)) 
}

%- maybe also `usage' for other objects documented here.
\arguments{
  \item{nw}{an object of class \code{\link{network}}, from which arrows
    are added/removed/turned.} 
  \item{df}{a data frame used for learning the network, see
    \code{\link{network}}.} 
  \item{prior}{a list describing parameter priors, generated by
    \code{\link{jointprior}}.} 
  \item{trylist}{a list, used internally for reusing learning of nodes,
    see \code{\link{maketrylist}}.} 
}

\details{
  Given the starting network, a list of networks is created with exactly
  one arrow added/turned/removed. All possible networks (with the
  restrictions described in \code{\link{insert}}) are returned in
  the list of networks. All networks are learned with the data in
  \code{df} using the prior information in \code{prior}. The functions
  are used by \code{\link{autosearch}}.  
}

\seealso{\code{\link{heuristic}},
  \code{\link{autosearch}},
  \code{\link{insert}},
  \code{\link{addarrows}},
  \code{\link{network}},
  \code{\link{networkfamily}}
  }

\value{A list with two elements
  \item{nw}{an object of class \code{\link{networkfamily}}, with all
      created networks. All networks have been learned.}
  \item{trylist}{an updated list, used internally for reusing learning
    of nodes, see \code{\link{maketrylist}}.}
}

\references{
  Further information about \bold{deal} can be found at:\cr
  \url{http://www.math.auc.dk/novo/deal}.
}

\author{
  Susanne Gammelgaard Bttcher \email{alma@math.auc.dk}, \cr
  Claus Dethlefsen \email{dethlef@math.auc.dk}.
}

%\note{ ~~further notes~~ }

% ~Make other sections like WARNING with \section{WARNING }{....} ~

\examples{
data(rats)
fit        <- network(rats)
fit.prior  <- jointprior(fit,12)
fit        <- learn(fit,rats,fit.prior)$nw
rats.extra <- addarrow(fit,rats,fit.prior)$nw
plot(rats.extra)
rats.extra2<- addarrow(rats.extra[[2]],rats,fit.prior)$nw
plot(rats.extra2)
rats.extra3<- turnarrow(rats.extra2[[2]],rats,fit.prior)$nw
plot(rats.extra3)
rats.extra4<- removearrow(rats.extra2[[2]],rats,fit.prior)$nw
plot(rats.extra4)
}

\keyword{iplot}
